# Changelog
## 0.0.26 - 2025-03-25
## 0.0.37 - 2025-04-04

* [REFACTOR] adding box AI api multiple file dupport (f88be7b)
* [REFACTOR] adding box AI api multiple file dupport (1b98433)
* [REFACTOR] adjusting imports (d693c1b)
* Update version to 0.0.36 and changelog (2cc5134)
## 0.0.36 - 2025-04-04

* [REFACTOR] exposing util classes (a541cfc)
* [REFACTOR] exposing util classes (9600346)
* Update version to 0.0.35 and changelog (35473eb)
## 0.0.35 - 2025-04-04

* [REFACTOR] converting box ai responses into agnostic dictionaries (561e36e)
* major refactor, box api break up, Alex file and folder operations (1c6ac5d)
* Update version to 0.0.34 and changelog (737c965)
## 0.0.34 - 2025-03-25

* exporting box objects (06f2cb7)
* Update version to 0.0.33 and changelog (338b92b)
## 0.0.33 - 2025-03-25

* exporting box objects (03a23dd)
* Update version to 0.0.32 and changelog (6caa55b)
## 0.0.32 - 2025-03-25

* publishing to pypi (3db0199)

* CI/CD script (25e01ee)
* Update version to 0.0.25 and changelog (37902d0)
## 0.0.25 - 2025-03-25

* CI/CD script (7f76549)
* Update version to 0.0.23 and changelog (742d19f)